@@ -1,6 +1,6 @@
 package Net::DNS::Packet;
 
-# $Id: Packet.pm,v 1.14 2003/01/28 07:12:36 ctriv Exp $
+# $Id: Packet.pm,v 1.17 2003/05/25 05:15:03 ctriv Exp $
 
 use strict;
 use vars qw(@ISA @EXPORT_OK $VERSION $AUTOLOAD);
@@ -14,7 +14,6 @@ use Net::DNS;
 use Net::DNS::Question;
 use Net::DNS::RR;
 
-
 $VERSION = $Net::DNS::VERSION;
 
 =head1 NAME
@@ -469,7 +468,7 @@ sub answerfrom {
 
 Returns the size of the packet in bytes as it was received from a
 nameserver.  User-created packets will return undef for this method
-(use C<length $packet>->C<data> instead).
+(use C<<length $packet->data>> instead).
 
 =cut
 
@@ -682,8 +681,12 @@ Returns B<(undef, undef)> if the domain name couldn't be expanded.
 # '
 sub dn_expand {
 	my ($packet, $offset) = @_;
-	my %seen;
-	dn_expand2($packet, $offset, \%seen);
+
+	if (defined &dn_expand_XS) {
+		return dn_expand_XS($packet, $offset);
+	} else {
+		return dn_expand2($packet, $offset, {});
+	}
 }
 
 sub dn_expand2 {
